==> qtjambi-webenginewidgets-5.15.8-sources.jar: io/qt/webengine/widgets/QWebEngineHistoryItem.java <==
package io.qt.webengine.widgets;


/**
 * <p>Java wrapper for Qt class QWebEngineHistoryItem</p>
 */
public class QWebEngineHistoryItem extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QWebEngineHistoryItem(io.qt.webengine.widgets.QWebEngineHistoryItem other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineHistoryItem instance, io.qt.webengine.widgets.QWebEngineHistoryItem other);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl iconUrl(){
        return iconUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl iconUrl_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QDateTime lastVisited(){
        return lastVisited_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QDateTime lastVisited_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void set(io.qt.webengine.widgets.QWebEngineHistoryItem other){
        set_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void set_native_cref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl originalUrl(){
        return originalUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl originalUrl_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void swap(io.qt.webengine.widgets.QWebEngineHistoryItem other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final java.lang.String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineHistoryItem(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QWebEngineHistoryItem clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebEngineHistoryItem clone_native(long __this_nativeId);
}

==> qtjambi-webenginewidgets-5.15.12-sources.jar: io/qt/webengine/widgets/QWebEngineHistoryItem.java <==
package io.qt.webengine.widgets;


/**
 * <p>Java wrapper for Qt class QWebEngineHistoryItem</p>
 */
public final class QWebEngineHistoryItem extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QWebEngineHistoryItem(io.qt.webengine.widgets.QWebEngineHistoryItem other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineHistoryItem instance, io.qt.webengine.widgets.QWebEngineHistoryItem other);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl iconUrl(){
        return iconUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl iconUrl_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QDateTime lastVisited(){
        return lastVisited_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QDateTime lastVisited_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void set(io.qt.webengine.widgets.QWebEngineHistoryItem other){
        set_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void set_native_cref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl originalUrl(){
        return originalUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl originalUrl_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void swap(io.qt.webengine.widgets.QWebEngineHistoryItem other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    @io.qt.QtUninvokable
    public final java.lang.String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineHistoryItem(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QWebEngineHistoryItem clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebEngineHistoryItem clone_native(long __this_nativeId);
}
